==> haskell-pango-0.13.6.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pango.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pango
version: 0.13.6.1
id: pango-0.13.6.1-5XNB2t9U5Ym8Te7ehkwDwX
key: pango-0.13.6.1-5XNB2t9U5Ym8Te7ehkwDwX
license: LGPL-2.1-only
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
author: Axel Simon, Duncan Coutts
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Pango text rendering engine.
description:
    This package provides a wrapper around the Pango C library that
    allows high-quality rendering of Unicode text. It can be used
    either with Cairo to output text in PDF, PS or other
    documents or with Gtk+ to display text on-screen.
category: Graphics
abi: f17be3f819d880e52f9ea1a41c0570cf
exposed: True
exposed-modules:
    Graphics.Rendering.Pango Graphics.Rendering.Pango.Attributes
    Graphics.Rendering.Pango.BasicTypes Graphics.Rendering.Pango.Cairo
    Graphics.Rendering.Pango.Context Graphics.Rendering.Pango.Enums
    Graphics.Rendering.Pango.Font Graphics.Rendering.Pango.Layout
    Graphics.Rendering.Pango.Markup Graphics.Rendering.Pango.Rendering
    Graphics.Rendering.Pango.Structs Graphics.Rendering.Pango.Types
hidden-modules: Graphics.Rendering.Pango.GlyphStorage
                Graphics.Rendering.Pango.Description
import-dirs: /usr/lib/ghc-8.6.5/site-local/pango-0.13.6.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/pango-0.13.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pango-0.13.6.1
hs-libraries: HSpango-0.13.6.1-5XNB2t9U5Ym8Te7ehkwDwX
extra-libraries:
    pangocairo-1.0 cairo pango-1.0 gobject-2.0 glib-2.0 harfbuzz
include-dirs: /usr/include/cairo /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/lib/libffi-3.2.1/include
              /usr/include/pixman-1 /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/pango-1.0 /usr/include/fribidi
includes:
    hspango.h
depends:
    array-0.5.3.0 base-4.12.0.0 cairo-0.13.6.0-CRppg1TTUyHLcUDcpeA2DP
    containers-0.6.0.1 directory-1.3.3.0
    glib-0.13.7.1-LeWTQxlbeVCHoiMMSyq9fo mtl-2.2.2 pretty-1.1.3.6
    process-1.6.5.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-pango/html/pango.haddock
haddock-html: /usr/share/doc/haskell-pango/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pango-0.13.6.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pango.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pango
version: 0.13.6.1
id: pango-0.13.6.1-GXJH3Vii6nOK9zbuYenYOR
key: pango-0.13.6.1-GXJH3Vii6nOK9zbuYenYOR
license: LGPL-2.1-only
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
author: Axel Simon, Duncan Coutts
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Pango text rendering engine.
description:
    This package provides a wrapper around the Pango C library that
    allows high-quality rendering of Unicode text. It can be used
    either with Cairo to output text in PDF, PS or other
    documents or with Gtk+ to display text on-screen.
category: Graphics
abi: 459d6553653c5d73a8e747beeb761c77
exposed: True
exposed-modules:
    Graphics.Rendering.Pango Graphics.Rendering.Pango.Attributes
    Graphics.Rendering.Pango.BasicTypes Graphics.Rendering.Pango.Cairo
    Graphics.Rendering.Pango.Context Graphics.Rendering.Pango.Enums
    Graphics.Rendering.Pango.Font Graphics.Rendering.Pango.Layout
    Graphics.Rendering.Pango.Markup Graphics.Rendering.Pango.Rendering
    Graphics.Rendering.Pango.Structs Graphics.Rendering.Pango.Types
hidden-modules: Graphics.Rendering.Pango.GlyphStorage
                Graphics.Rendering.Pango.Description
import-dirs: /usr/lib/ghc-8.6.5/site-local/pango-0.13.6.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/pango-0.13.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pango-0.13.6.1
hs-libraries: HSpango-0.13.6.1-GXJH3Vii6nOK9zbuYenYOR
extra-libraries:
    pangocairo-1.0 cairo pango-1.0 gobject-2.0 glib-2.0 harfbuzz
include-dirs: /usr/include/cairo /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/lib/libffi-3.2.1/include
              /usr/include/pixman-1 /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/pango-1.0 /usr/include/fribidi
includes:
    hspango.h
depends:
    array-0.5.3.0 base-4.12.0.0 cairo-0.13.6.1-L6Hqm0CFC208FU91TS5cEx
    containers-0.6.0.1 directory-1.3.3.0
    glib-0.13.7.1-LeWTQxlbeVCHoiMMSyq9fo mtl-2.2.2 pretty-1.1.3.6
    process-1.6.5.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-pango/html/pango.haddock
haddock-html: /usr/share/doc/haskell-pango/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
